@@ -57,10 +57,11 @@ NAMESPACES_RESOURCE = Aliases(
     "namespaces",
 )
 MACHINES_RESOURCE = Aliases(
-    ["machines", "mach", "machs", "machine", "node", "nodes"],
+    ["machines", "mach", "machs", "machine"],
     "machine",
     "machines",
 )
+NODES_RESOURCE = Aliases(["nodes", "node"], "node", "nodes")
 PODS_RESOURCE = Aliases(["pods", "pod"], "pod", "pods")
 FINGERPRINTS_RESOURCE = Aliases(
     [
@@ -105,6 +106,7 @@ GET_RESOURCES: List[str] = [
     FINGERPRINTS_RESOURCE.name_plural,
     MACHINES_RESOURCE.name_plural,
     NAMESPACES_RESOURCE.name_plural,
+    NODES_RESOURCE.name_plural,
     PODS_RESOURCE.name_plural,
     POLICIES_RESOURCE.name_plural,
 ]
@@ -257,6 +259,7 @@ METADATA_TAGS_FIELD = "tags"
 METADATA_TYPE_FIELD = "type"
 METADATA_UID_FIELD = "uid"
 METADATA_CREATE_TIME = "creationTimestamp"
+METADATA_NAMESPACE_FIELD = "namespace"
 NET_POLICY_FIELD = "networkPolicy"
 PROC_POLICY_FIELD = "processPolicy"
 FIRST_TIMESTAMP_FIELD = "firstTimestamp"
